@@ -7,9 +7,10 @@ with open(os.path.join(__path__[0], '__init__.py')) as f:
     init_text = f.read()
     __version__ = re.search(r'__version__\s*=\s*[\'\"](.+?)[\'\"]', init_text).group(1)
 import sys
+sys.setrecursionlimit(10000)
 import ast
-import json
 import copy
+import json
 import logging
 import warnings
 warnings.simplefilter(action='ignore', category=FutureWarning)
@@ -72,6 +73,7 @@ def convert(
     enable_batchmatmul_unfold: Optional[bool] = False,
     disable_suppression_flextranspose: Optional[bool] = False,
     number_of_dimensions_after_flextranspose_compression: Optional[int] = 5,
+    optimization_for_gpu_delegate: Optional[bool] = False,
     replace_argmax_to_reducemax_and_indicies_is_int64: Optional[bool] = False,
     replace_argmax_to_reducemax_and_indicies_is_float32: Optional[bool] = False,
     replace_argmax_to_fused_argmax_and_indicies_is_int64: Optional[bool] = False,
@@ -257,6 +259,10 @@ def convert(
         Number of Transpose OP dimensions generated after avoiding FlexTranspose generation.\n
         Default: 5
 
+    optimization_for_gpu_delegate: Optional[bool]
+        Replace operations that do not support gpu delegate with those\n
+        that do as much as possible.
+
     replace_argmax_to_reducemax_and_indicies_is_int64: Optional[bool]
         Replace ArgMax with a ReduceMax. The returned indicies are int64.\n
         Only one of replace_argmax_to_reducemax_and_indicies_is_int64 and \n
@@ -609,6 +615,7 @@ def convert(
         'disable_group_convolution': disable_group_convolution,
         'disable_suppression_flextranspose': disable_suppression_flextranspose,
         'number_of_dimensions_after_flextranspose_compression': number_of_dimensions_after_flextranspose_compression,
+        'optimization_for_gpu_delegate': optimization_for_gpu_delegate,
         'replace_argmax_to_reducemax_and_indicies_is_int64': replace_argmax_to_reducemax_and_indicies_is_int64,
         'replace_argmax_to_reducemax_and_indicies_is_float32': replace_argmax_to_reducemax_and_indicies_is_float32,
         'replace_argmax_to_fused_argmax_and_indicies_is_int64': replace_argmax_to_fused_argmax_and_indicies_is_int64,
@@ -1163,6 +1170,7 @@ def convert(
                     onnx_output_name: [
                         onnx_tensor,
                         matched_flg, <--- 0: Unmatched, 1: Matched, 2: Skipped
+                        max_abs_err,
                     ]
                 }
             """
@@ -1175,13 +1183,21 @@ def convert(
             for onnx_output_name, checked_value in check_results.items():
                 validated_onnx_tensor: np.ndarray = checked_value[0]
                 matched_flg: int = checked_value[1]
+                max_abs_err: Any = checked_value[2]
                 message = ''
                 if matched_flg == 0:
-                    message = f'{Color.GREEN}validate_result{Color.RESET}: {Color.REVERCE}{Color.YELLOW} Unmatched {Color.RESET}'
+                    message = \
+                        f'{Color.GREEN}validate_result{Color.RESET}: ' +\
+                        f'{Color.REVERCE}{Color.YELLOW} Unmatched {Color.RESET} ' +\
+                        f'{Color.GREEN}max_abs_error{Color.RESET}: {max_abs_err}'
                 elif matched_flg == 1:
-                    message = f'{Color.GREEN}validate_result{Color.RESET}: {Color.REVERCE}{Color.GREEN} Matches {Color.RESET}'
+                    message = \
+                        f'{Color.GREEN}validate_result{Color.RESET}: ' +\
+                        f'{Color.REVERCE}{Color.GREEN} Matches {Color.RESET}'
                 elif matched_flg == 2:
-                    message = f'{Color.GREEN}validate_result{Color.RESET}: {Color.REVERCE}{Color.BLUE} Skipped {Color.RESET}'
+                    message = \
+                        f'{Color.GREEN}validate_result{Color.RESET}: ' +\
+                        f'{Color.REVERCE}{Color.BLUE} Skipped {Color.RESET}'
                 print(
                     f'{Color.GREEN}INFO:{Color.RESET} '+
                     f'{Color.GREEN}onnx_output_name{Color.RESET}: {onnx_output_name} '+
@@ -1440,6 +1456,14 @@ def main():
             'Number of Transpose OP dimensions generated after avoiding FlexTranspose generation. \n' +
             'Default: 5'
     )
+    parser.add_argument(
+        '-ofgd',
+        '--optimization_for_gpu_delegate',
+        action='store_true',
+        help=\
+            'Replace operations that do not support gpu delegate with those \n' +
+            'that do as much as possible.'
+    )
     rar_group = parser.add_mutually_exclusive_group()
     rar_group.add_argument(
         '-rari64',
@@ -1708,6 +1732,7 @@ def main():
         enable_batchmatmul_unfold=args.enable_batchmatmul_unfold,
         disable_suppression_flextranspose=args.disable_suppression_flextranspose,
         number_of_dimensions_after_flextranspose_compression=args.number_of_dimensions_after_flextranspose_compression,
+        optimization_for_gpu_delegate=args.optimization_for_gpu_delegate,
         replace_argmax_to_reducemax_and_indicies_is_int64=args.replace_argmax_to_reducemax_and_indicies_is_int64,
         replace_argmax_to_reducemax_and_indicies_is_float32=args.replace_argmax_to_reducemax_and_indicies_is_float32,
         replace_argmax_to_fused_argmax_and_indicies_is_int64=args.replace_argmax_to_fused_argmax_and_indicies_is_int64,
